#!/usr/bin/env node
/*!
 * gitmars v7.0.0-beta.1
 * 这是一个git工作流工具
 * (c) 2021-2024 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import inquirer from 'inquirer';
import chalk from 'chalk';
import { createArgs } from '@gitmars/utils';
import { runJenkins } from '@gitmars/build';
import lang from './common/local.mjs';
import { cmdConfig } from './conf/build.mjs';

const { t } = lang;
const { red, yellow } = chalk;
const { args, options } = cmdConfig;
program.name("gitm build").usage("<project> [-e --env [env]] [-a --app [app]] [-d --data <data>] [-c --confirm]").description(t("buildJenkins"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(async (project, opt) => {
  const data = JSON.parse(opt.data || "{}");
  let confirm = opt.confirm;
  if (!confirm || opt.data && opt.data !== "{}") {
    let message = `${yellow(t("Please double check the following build parameters"))}
${t(
      "Project Name"
    )}: ${red(project)}
${t("Code Branch")}: ${red(opt.env)}
${t("Build Application")}: ${red(
      opt.app
    )}`;
    message += `
${t("Interface Environment")}: ${red(data.build_api_env || "production")}`;
    if ("mini_program" in data)
      message += `
${t("Experience version pushed to")}: ${red(data.mini_program || t("Push to templates only"))}`;
    if ("description" in data)
      message += `
${t("Version Description")}: ${red(data.description)}`;
    if ("clean" in data)
      message += `
${t("Clean node modules (use with caution)")}: ${red(data.clean)}`;
    confirm = (await inquirer.prompt({
      type: "confirm",
      name: "confirm",
      message
    })).confirm;
  }
  if (!confirm)
    sh.exit(1);
  else
    runJenkins({
      env: opt.env,
      project,
      app: opt.app,
      data: opt.data
    });
});
program.parse(process.argv);
